@@ -643,15 +643,24 @@ Boolean labeltext(int keypressed, char *clientdata)
       else if (eventmode == CATTEXT_MODE) {
 	 objectptr libobj;
 	 stringpart *oldname;
+	 int page, libnum;
 
 	 /* Get the library object whose name matches the original string */
 	 oldname = get_original_string(curlabel);
-	 libobj = NameToObject(oldname->nextpart->data.string, NULL, FALSE);
-	 if (libobj != NULL) {
+	 if ((libobj = NameToObject(oldname->nextpart->data.string, NULL, FALSE))
+			!= NULL) {
 
-            /* set name of object to new string */
+            /* Set name of object to new string.  Don't overwrite the	*/
+	    /* object's technology *unless* the new string has a	*/
+	    /* namespace, in which case the object's technology gets	*/
+	    /* changed.							*/
 
-	    strcpy(libobj->name, curlabel->string->nextpart->data.string);
+	    char *techptr, *libobjname = libobj->name;
+	    if ((techptr = strstr(libobjname, "::")) != NULL &&
+			(strstr(curlabel->string->nextpart->data.string, "::")
+			== NULL))
+	       libobjname = techptr + 2;
+	    strcpy(libobjname, curlabel->string->nextpart->data.string);
 
 	    /* If checkname() alters the name, it has to be copied back to */
 	    /* the catalog label for the object.			   */
@@ -665,7 +674,26 @@ Boolean labeltext(int keypressed, char *clientdata)
                XcSetFunction(GXcopy);
 	       redrawtext(curlabel);
 	    }
+	    AddObjectTechnology(libobj);
 	 }
+
+	 /* Check if we altered a page name */
+	 else if ((libobj = NameToPageObject(oldname->nextpart->data.string,
+		NULL, &page)) != NULL) {
+	    strcpy(libobj->name, curlabel->string->nextpart->data.string);
+	    renamepage(page);
+	 }
+
+	 /* Check if we altered a library name */
+	 else if ((libnum = NameToLibrary(oldname->nextpart->data.string)) != -1) {
+	    libobj = xobjs.libtop[libnum + LIBRARY]->thisobject;
+	    strcpy(libobj->name, curlabel->string->nextpart->data.string);
+	 }
+ 	 else {
+	    Wprintf("Error:  Cannot match name to any object, page, or library!");
+	    refresh(NULL, NULL, NULL);
+         }
+
          eventmode = CATALOG_MODE;
 	 unselect_all();
       }
@@ -886,11 +914,11 @@ Boolean labeltext(int keypressed, char *clientdata)
    if (do_redraw) {
       short beglength;
 
-      tmpext = ULength(curlabel->string, areawin->topinstance, curlabel->scale,
+      tmpext = ULength(curlabel, areawin->topinstance, curlabel->scale,
 		textpos, NULL);
       beglength = tmpext.width;
 	
-      tmpext = ULength(curlabel->string, areawin->topinstance, curlabel->scale,
+      tmpext = ULength(curlabel, areawin->topinstance, curlabel->scale,
 		0, NULL);
       tmplength = tmpext.width;
       tmpheight = (short)(curlabel->scale * TEXTHEIGHT);
