@@ -730,7 +730,7 @@ void UTransformbyCTM(Matrix *ctm, XPoint *ipoints, XPoint *points, short number)
 {
    pointlist current, ptptr = points;
    float fx, fy;
-   short tmpx;
+   /* short tmpx; (jdk) */
 
    for (current = ipoints; current < ipoints + number; current++, ptptr++) {
       fx = ctm->a * (float)current->x + ctm->b * (float)current->y + ctm->c;
@@ -1724,7 +1724,7 @@ void UDrawRescaleBox(XPoint *corner)
    float	savescale, newscale, lastscale, tempscale;
    long		mindist, testdist, lastmindist;
    labelptr	rlab;
-   int		i, j, idx;
+   int		i, j; /* , idx; (jdk) */
 
    /* To be done---draw a box around each selected part, not	*/
    /* just the first one.					*/
