@@ -924,7 +924,7 @@ proc xcircuit::promptreadedif {} {
   .filelist.textent.title.field configure -text "Select EDIF 2.0.0 file to parse:"
   .filelist.textent.txt delete 0 end
   xcircuit::popupfilelist
-  xcircuit::removeliblist .filelist
+  xcircuit::removelists .filelist
 }
 
 #---------------------------------------------------------------------------
