@@ -78,7 +78,7 @@ u_char param_select[] = {
 
 #ifdef TCL_WRAPPER
 #ifndef _MSC_VER
-xcWidget *param_buttons[] = {
+xcWidget *param_buttons[] = { NULL              /* (jdk) */
    /* To be done---map buttons to Tk_Windows! */
 };
 #else
@@ -326,7 +326,7 @@ void std_eparam(genericptr gen, char *key)
 
 void indicateparams(genericptr thiselem)
 {
-   int i, j, k, which;
+  int k; /* , i, j, which; (jdk) */
    oparamptr ops;
    eparamptr epp;
 
@@ -373,7 +373,7 @@ void setparammarks(genericptr thiselem)
 {
    /* Set GUI variables associated with the "parameter" menu.	*/
 
-   int i, j, paramno;
+  int i; /* , j, paramno; (jdk) */
    oparamptr ops;
    eparamptr epp;
 
@@ -381,7 +381,7 @@ void setparammarks(genericptr thiselem)
    const char *paramvars[] = {"positionparam", "substringparam", "xparam",
 	"yparam", "styleparam", "justparam", "startparam", "endparam",
 	"radiusparam", "minorparam", "rotationparam", "scaleparam",
-	"linewidthparam", "colorparam"};
+			      "linewidthparam", "colorparam", NULL};   /* (jdk) */
 
    /* Reset all variables to false */
    for (i = 0; i < 14; i++)
@@ -452,10 +452,10 @@ void setparammarks(genericptr thiselem)
 int opsubstitute(objectptr thisobj, objinstptr pinst)
 {
    genericptr *eptr, thiselem;
-   int i, j, k, ival;
+   int k, ival; /* i, j, (jdk) */
    char *key;
    float fval;
-   oparamptr dps, ops, cps;
+   oparamptr dps, ops; /* , cps; (jdk) */
    eparamptr epp;
    XPoint *setpt;
    Boolean needrecalc;	/* for arcs and splines */
@@ -784,7 +784,7 @@ void pwriteback(objinstptr thisinst)
    objinstptr pinst;
    eparamptr epp;
    oparamptr ops, ips;
-   int i, j, k, *destivalptr, found;
+   int k, *destivalptr, found; /*  i, j, (jdk) */
    XPoint *setpt;
    Boolean changed, need_redraw = FALSE;
    union {
@@ -991,7 +991,7 @@ void replaceparams(objinstptr thisinst)
 {
    objectptr thisobj;
    oparamptr ops, ips;
-   int i, nullparms = 0;
+   /* int i, nullparms = 0; (jdk) */
 
    thisobj = thisinst->thisobject;
 
@@ -1335,7 +1335,7 @@ void makenumericalp(genericptr *gelem, u_int mode, char *key)
 
    static char *param_keys[] = {
 	"p_gps", "p_str", "p_xps", "p_yps", "p_sty", "p_jst", "p_an1",
-	"p_an2", "p_rad", "p_axs", "p_rot", "p_scl", "p_wid", "p_col"
+	"p_an2", "p_rad", "p_axs", "p_rot", "p_scl", "p_wid", "p_col", NULL  /* (jdk) */
    };
 
    /* Parameterized strings are handled by makeparam() */
@@ -1760,7 +1760,7 @@ void makeparam(labelptr thislabel, char *key)
 void destroyinst(objinstptr tinst, objectptr refobj, char *key)
 {
    oparamptr ops;
-   short k;
+   /* short k; (jdk) */
 
    if (tinst->thisobject == refobj) {
       ops = match_instance_param(tinst, key);
