@@ -662,6 +662,38 @@ void collectsubschems(int toppage)
    free((char *)pagelist);
 }
 
+/*------------------------------------------------------*/
+/* compare_qualified(str1, str2) ---			*/
+/*							*/
+/* 	String comparison for technology-qualified	*/
+/*	names.  str2" must be a fully-qualified name.	*/
+/*	"str1" may be qualified or unqualified.  If	*/
+/*	unqualified, compare_qualified will return TRUE	*/
+/*	for any "str2" that matches the name part of	*/
+/*	the technology::name format.			*/
+/*							*/
+/*	Return value:  TRUE if match, FALSE if not.	*/
+/*------------------------------------------------------*/
+
+Boolean compare_qualified(char *str1, char *str2)
+{
+   char *sptr1, *sptr2;
+   Boolean qual1, qual2;
+
+   sptr2 = strstr(str2, "::");
+   qual2 = (sptr2 == NULL) ? FALSE : TRUE;
+
+   if (!qual2) return (!strcmp(str1, str2));
+
+   sptr1 = strstr(str1, "::");
+   qual1 = (sptr1 == NULL) ? FALSE : TRUE;
+
+   if (qual1) return (!strcmp(str1, str2));
+
+   sptr2 += 2;
+   return (!strcmp(str1, sptr2));
+}
+
 /*-------------------------------------------------------*/
 /* Check if top-level page is the same name as a library */
 /* object; if so, connect it.				 */
@@ -683,7 +715,7 @@ int checkschem(objectptr thisobj, char *cname)
       for (j = 0; j < xobjs.userlibs[i].number; j++) {
 	 tlib = xobjs.userlibs[i].library + j;
 
-         if (!strcmp(cname, (*tlib)->name)) {
+         if (compare_qualified(cname, (*tlib)->name)) {
 	    thisobj->symschem = (*tlib);
 	    thisobj->schemtype = PRIMARY;
 	    (*tlib)->symschem = thisobj;
@@ -710,7 +742,7 @@ int checksym(objectptr symobj, char *cname)
    for (cpage = 0; cpage < xobjs.pages; cpage++) {
       if (xobjs.pagelist[cpage]->pageinst != NULL) {
          checkpage = xobjs.pagelist[cpage]->pageinst->thisobject;
-         if (!strcmp(checkpage->name, cname)) {
+         if (compare_qualified(cname, checkpage->name)) {
 	    symobj->symschem = checkpage;
 	    symobj->schemtype = SYMBOL;
 	    checkpage->symschem = symobj;
