@@ -383,7 +383,7 @@ selection *genselectelement(short class, u_char mode, objectptr selobj,
 		objinstptr selinst)
 {
    selection	*rselect = NULL;
-   short	*newselect;
+   /* short	*newselect; (jdk) */
    genericptr	*curgen;
    XPoint 	newboxpts[4];
    Boolean	selected;
@@ -868,7 +868,7 @@ selection *recurselect(short class, u_char mode, pushlistptr *seltop)
 {
    selection *rselect, *rcheck, *lastselect;
    genericptr rgen;
-   short i, *selectobj, numselect, origselect;
+   short i; /* , *selectobj, numselect, origselect; (jdk) */
    short rclass;
    objectptr selobj;
    objinstptr selinst;
@@ -989,7 +989,7 @@ void startselect()
 void trackselarea()
 {
    XPoint newpos;
-   u_int  nullui;
+   /* u_int  nullui; (jdk) */
 
    newpos = UGetCursorPos();
    if (newpos.x == areawin->save.x && newpos.y == areawin->save.y) return;
@@ -1008,7 +1008,7 @@ void trackselarea()
 void trackrescale()
 {
    XPoint newpos;
-   u_int  nullui;
+   /* u_int  nullui; (jdk) */
 
    newpos = UGetCursorPos();
    if (newpos.x == areawin->save.x && newpos.y == areawin->save.y) return;
@@ -1080,7 +1080,7 @@ Boolean compareselection(selection *sa, selection *sb)
 short *recurse_select_element(short class, u_char mode) {
    pushlistptr seltop, nextptr;
    selection *rselect;
-   short *newselect, *desel, localpick;
+   short *newselect, localpick; /* *desel, (jdk) */
    static short pick = 0;
    static selection *saveselect = NULL;
    int i, j, k, ilast, jlast;
