@@ -349,7 +349,7 @@ void undelete_one_element(objinstptr thisinst, genericptr thiselem)
 void register_for_undo(u_int type, u_char mode, objinstptr thisinst, ...)
 {
    va_list args;
-   int usize, drawmode, nval, oval, *idata, snum, deltax, deltay, dir;
+   int drawmode, nval, oval, *idata, snum, deltax, deltay, dir; /*  usize, (jdk) */
    short *slist;
    objectptr delobj;
    objinstptr newinst;
@@ -357,7 +357,7 @@ void register_for_undo(u_int type, u_char mode, objinstptr thisinst, ...)
    uselection *srec;
    editelement *erec;
    scaleinfo *escale;
-   genericptr egen, newgen;
+   genericptr egen; /* , newgen; (jdk) */
    XPoint *fpoint;
    double scale;
 
@@ -565,7 +565,7 @@ void register_for_undo(u_int type, u_char mode, objinstptr thisinst, ...)
 
 short undo_one_action()
 {
-   Undoptr thisrecord, chkrecord;
+  Undoptr thisrecord; /* , chkrecord; (jdk) */
    objectptr thisobj;
    objinstptr thisinst;
    uselection *srec;
@@ -573,7 +573,7 @@ short undo_one_action()
    scaleinfo *escale;
    short *slist;
    XPoint *delta, position;
-   int i, snum, npage, opage;
+   int i, snum; /* , npage, opage; (jdk) */
    int savemode;
    float fnum;
    genericptr egen;
@@ -924,7 +924,7 @@ short redo_one_action()
    uselection *srec;
    editelement *erec;
    scaleinfo *escale;
-   int i, tpage, snum;
+   int i, snum; /*  tpage, (jdk) */
    int savemode;
    float fnum;
    labelptr thislabel;
@@ -1351,7 +1351,7 @@ void free_undo_data(Undoptr thisrecord, u_char mode)
 
 void free_undo_record(Undoptr thisrecord)
 {
-   Undoptr nextrecord, lastrecord;
+  /* Undoptr nextrecord, lastrecord; (jdk) */
 
    /* Reset the master list pointers */
 
@@ -1379,7 +1379,7 @@ void free_undo_record(Undoptr thisrecord)
 
 void free_redo_record(Undoptr thisrecord)
 {
-   Undoptr nextrecord, lastrecord;
+  /* Undoptr nextrecord, lastrecord; (jdk) */
 
    /* Reset the master list pointers */
 
