@@ -334,12 +334,14 @@ u_short countchanges(char **promptstr)
 	 changes++;
 	 if (promptstr != NULL) {
 	    fname = ns->filename;
-	    slen += strlen(fname) + 2;
-	    *promptstr = (char *)realloc(*promptstr, slen);
-	    if ((words % 8) == 0) strcat(*promptstr, ",\n");
-	    else if (changes > 0) strcat(*promptstr, ", ");
-	    strcat(*promptstr, fname);
-	    words++;
+	    if (fname != NULL) {
+	       slen += strlen(fname) + 2;
+	       *promptstr = (char *)realloc(*promptstr, slen);
+	       if ((words % 8) == 0) strcat(*promptstr, ",\n");
+	       else if (changes > 0) strcat(*promptstr, ", ");
+	       strcat(*promptstr, fname);
+	       words++;
+	    }
 	 }
       }
    }
