@@ -272,6 +272,8 @@ typedef struct {
 #define INTSEGS		(SPLINESEGS - 2)
 #define LASTSEG		(SPLINESEGS - 3)
 
+#define NOFILENAME	(char *)(-1)
+
 #define FONTHEIGHT(y)	 (y->ascent + y->descent + 6) 
 #define ROWHEIGHT	 FONTHEIGHT(appdata.xcfont)
 #define FILECHARASCENT   (appdata.filefont->ascent)
@@ -477,6 +479,7 @@ enum loadmodes {IMPORT = 1, PSBKGROUND, SCRIPT, RECOVER,
 #define SYMBOL 3		/* Symbol associated with a schematic */
 #define FUNDAMENTAL 4		/* Standalone symbol */
 #define NONETWORK 5		/* Do not netlist this object */
+#define GLYPH 6			/* Symbol is a font glyph */
 
 #define LOCAL 1
 #define GLOBAL 2
@@ -990,7 +993,7 @@ typedef struct _matrix {
 /* button tap/press definitions 					*/
 /*----------------------------------------------------------------------*/
 
-#define PRESSTIME	150	/* milliseconds of push to be a "press" */
+#define PRESSTIME	200	/* milliseconds of push to be a "press" */
 
 /*----------------------------------------------------------------------*/
 /* object name alias structures						*/
@@ -1387,13 +1390,20 @@ typedef struct _undostack {
 /* the library page, and not be destroyed on every call to "composelib"	*/
 
 typedef struct {
-   char		*filename;	/* Last file loaded into the library */
-   char		flags;		/* Flags for library page (changed, read-only) */
    short	number;
    objectptr	*library;
    liblistptr	instlist;	/* List of instances */
 } Library;
 
+typedef struct _Technology *TechPtr;
+
+typedef struct _Technology {
+   char		flags;		/* Flags for library page (changed, read-only) */
+   char		*technology;	/* Namespace name (without the "::") */
+   char		*filename;	/* Library file associated with technology */
+   TechPtr 	next;		/* Linked list */
+} Technology;
+
 /* Known flags for library pages */
 
 #define LIBRARY_CHANGED		0x01
@@ -1414,6 +1424,7 @@ typedef struct {
    short	do_replace;
    Boolean	filefilter;	/* Is the file list filtered? */
    Boolean	hold;		/* allow HOLD modifiers on buttons */
+   Boolean	showtech;	/* Write technology names in library */
    u_short	new_changes;
    char		suspend;	/* suspend graphics updates if TRUE */
    short	numlibs;
@@ -1423,6 +1434,7 @@ typedef struct {
    Undoptr	redostack;	/* actions to redo */
    Library	fontlib;
    Library	*userlibs;
+   TechPtr 	technologies;
    objinstptr   *libtop;
    Imagedata	*imagelist;
    short	images;
